From 8f05627747697632c1e55ea729556ed12584bd21 Mon Sep 17 00:00:00 2001
From: 3d-gussner <3d.gussner@gmail.com>
Date: Fri, 25 Oct 2019 13:04:04 +0200
Subject: [PATCH] Update #1 gcodes doxygen documentation added some RepRap
G-codes Wiki external links.
---
Firmware/Marlin_main.cpp | 42 ++++++++++++++++++++++++++--------------
1 file changed, 27 insertions(+), 15 deletions(-)
diff --git a/Firmware/Marlin_main.cpp b/Firmware/Marlin_main.cpp
index a2cbece56..f4971efc6 100755
--- a/Firmware/Marlin_main.cpp
+++ b/Firmware/Marlin_main.cpp
@@ -3322,8 +3322,7 @@ extern uint8_t st_backlash_y;
//! @brief Parse and process commands
//!
-//! look here for descriptions of G-codes: http://linuxcnc.org/handbook/gcode/g-code.html
-//! http://objects.reprap.org/wiki/Mendel_User_Manual:_RepRapGCodes
+//! look here for descriptions of G-codes: https://reprap.org/wiki/G-code
//!
//!
//! Implemented Codes
@@ -3663,7 +3662,7 @@ void process_commands()
} else if( code_seen("FANPINTST") ){
gcode_PRUSA_BadRAMBoFanTest();
- }else if (code_seen("FAN")) { //! PRUSA FAN
+ }else if (code_seen("FAN")) { // PRUSA FAN
printf_P(_N("E0:%d RPM\nPRN0:%d RPM\n"), 60*fan_speed[0], 60*fan_speed[1]);
}else if (code_seen("fn")) { // PRUSA fn
if (farm_mode) {
@@ -3838,7 +3837,7 @@ eeprom_update_word((uint16_t*)EEPROM_NOZZLE_DIAMETER_uM,0xFFFF);
switch (gcode_in_progress)
{
- //! ### G0, G1 - Coordinated movement X Y Z E
+ //! ### G0, G1 - Coordinated movement X Y Z E G0 & G1: Move
// --------------------------------------
case 0: // G0 -> G1
case 1: // G1
@@ -4038,7 +4037,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
}
break;
- //! ### G2 - CW ARC
+ //! ### G2 - CW ARC G2 & G3: Controlled Arc Move
// ------------------------------
case 2:
if(Stopped == false) {
@@ -4048,7 +4047,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
break;
- //! ### G3 - CCW ARC
+ //! ### G3 - CCW ARC G2 & G3: Controlled Arc Move
// -------------------------------
case 3:
if(Stopped == false) {
@@ -4058,7 +4057,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
break;
- //! ### G4 - Dwell
+ //! ### G4 - Dwell G4: Dwell
// -------------------------------
case 4:
codenum = 0;
@@ -4077,7 +4076,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
#ifdef FWRETRACT
- //! ### G10 Retract
+ //! ### G10 - Retract G10: Retract
// ------------------------------
case 10:
#if EXTRUDERS > 1
@@ -4089,7 +4088,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
break;
- //! ### G11 - Retract recover
+ //! ### G11 - Retract recover G11: Unretract
// -----------------------------
case 11:
#if EXTRUDERS > 1
@@ -4101,8 +4100,21 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
#endif //FWRETRACT
- //! ### G28 - Home all Axis one at a time
- // --------------------------------------------
+ /*!
+ *
+ ### G28 - Home all Axis one at a time G28: Move to Origin (Home)
+ Unsing G28 without any paramters will perfom on the Prusa i3 printers home AND mesh bed leveling, while the default G-code G28 is just homeing the printer
+
+ G28 [ X | Y | Z | W | C ]
+
+ - `X` - Flag to go back to the X axis origin
+ - `Y` - Flag to go back to the Y axis origin
+ - `Z` - Flag to go back to the Z axis origin
+ - `W` - Suppress mesh bed leveling
+ - `C` - Calibrate X and Y origin (home)
+ *
+ */
+ // ------------------------------
case 28:
{
long home_x_value = 0;
@@ -4134,7 +4146,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
#ifdef ENABLE_AUTO_BED_LEVELING
- //! ### G29 - Detailed Z-Probe
+ //! ### G29 - Detailed Z-Probe G29: Detailed Z-Probe
// --------------------------------
case 29:
{
@@ -4280,7 +4292,7 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
break;
#ifndef Z_PROBE_SLED
- //! ### G30 - Single Z Probe
+ //! ### G30 - Single Z Probe G30: Single Z-Probe
// ------------------------------------
case 30:
{
@@ -4305,14 +4317,14 @@ if(eSoundMode!=e_SOUND_MODE_SILENT)
break;
#else
- //! ### G31 - Dock the sled
+ //! ### G31 - Dock the sled G31: Dock Z Probe sled
// ---------------------------
case 31:
dock_sled(true);
break;
- //! ### G32 - Undock the sled
+ //! ### G32 - Undock the sled G32: Undock Z Probe sled
// ----------------------------
case 32:
dock_sled(false);